==> zio-aws-elasticsearch_2.12-5.17.129.3-sources.jar: zio/aws/elasticsearch/model/ReservedElasticsearchInstanceOffering.scala <==
package zio.aws.elasticsearch.model
import zio.aws.elasticsearch.model.primitives.{Integer, GUID}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ReservedElasticsearchInstanceOffering(
    reservedElasticsearchInstanceOfferingId: Option[GUID] = None,
    elasticsearchInstanceType: Option[
      zio.aws.elasticsearch.model.ESPartitionInstanceType
    ] = None,
    duration: Option[Integer] = None,
    fixedPrice: Option[Double] = None,
    usagePrice: Option[Double] = None,
    currencyCode: Option[String] = None,
    paymentOption: Option[
      zio.aws.elasticsearch.model.ReservedElasticsearchInstancePaymentOption
    ] = None,
    recurringCharges: Option[
      Iterable[zio.aws.elasticsearch.model.RecurringCharge]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticsearch.model.ReservedElasticsearchInstanceOffering = {
    import ReservedElasticsearchInstanceOffering.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticsearch.model.ReservedElasticsearchInstanceOffering
      .builder()
      .optionallyWith(
        reservedElasticsearchInstanceOfferingId.map(value =>
          GUID.unwrap(value): java.lang.String
        )
      )(_.reservedElasticsearchInstanceOfferingId)
      .optionallyWith(elasticsearchInstanceType.map(value => value.unwrap))(
        _.elasticsearchInstanceType
      )
      .optionallyWith(
        duration.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.duration)
      .optionallyWith(fixedPrice.map(value => value: java.lang.Double))(
        _.fixedPrice
      )
      .optionallyWith(usagePrice.map(value => value: java.lang.Double))(
        _.usagePrice
      )
      .optionallyWith(currencyCode.map(value => value: java.lang.String))(
        _.currencyCode
      )
      .optionallyWith(paymentOption.map(value => value.unwrap))(_.paymentOption)
      .optionallyWith(
        recurringCharges.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.recurringCharges)
      .build()
  }
  def asReadOnly
      : zio.aws.elasticsearch.model.ReservedElasticsearchInstanceOffering.ReadOnly =
    zio.aws.elasticsearch.model.ReservedElasticsearchInstanceOffering
      .wrap(buildAwsValue())
}
object ReservedElasticsearchInstanceOffering {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticsearch.model.ReservedElasticsearchInstanceOffering
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.elasticsearch.model.ReservedElasticsearchInstanceOffering =
      zio.aws.elasticsearch.model.ReservedElasticsearchInstanceOffering(
        reservedElasticsearchInstanceOfferingId.map(value => value),
        elasticsearchInstanceType.map(value => value),
        duration.map(value => value),
        fixedPrice.map(value => value),
        usagePrice.map(value => value),
        currencyCode.map(value => value),
        paymentOption.map(value => value),
        recurringCharges.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def reservedElasticsearchInstanceOfferingId: Option[GUID]
    def elasticsearchInstanceType
        : Option[zio.aws.elasticsearch.model.ESPartitionInstanceType]
    def duration: Option[Integer]
    def fixedPrice: Option[Double]
    def usagePrice: Option[Double]
    def currencyCode: Option[String]
    def paymentOption: Option[
      zio.aws.elasticsearch.model.ReservedElasticsearchInstancePaymentOption
    ]
    def recurringCharges
        : Option[List[zio.aws.elasticsearch.model.RecurringCharge.ReadOnly]]
    def getReservedElasticsearchInstanceOfferingId: ZIO[Any, AwsError, GUID] =
      AwsError.unwrapOptionField(
        "reservedElasticsearchInstanceOfferingId",
        reservedElasticsearchInstanceOfferingId
      )
    def getElasticsearchInstanceType: ZIO[
      Any,
      AwsError,
      zio.aws.elasticsearch.model.ESPartitionInstanceType
    ] = AwsError.unwrapOptionField(
      "elasticsearchInstanceType",
      elasticsearchInstanceType
    )
    def getDuration: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("duration", duration)
    def getFixedPrice: ZIO[Any, AwsError, Double] =
      AwsError.unwrapOptionField("fixedPrice", fixedPrice)
    def getUsagePrice: ZIO[Any, AwsError, Double] =
      AwsError.unwrapOptionField("usagePrice", usagePrice)
    def getCurrencyCode: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("currencyCode", currencyCode)
    def getPaymentOption: ZIO[
      Any,
      AwsError,
      zio.aws.elasticsearch.model.ReservedElasticsearchInstancePaymentOption
    ] = AwsError.unwrapOptionField("paymentOption", paymentOption)
    def getRecurringCharges: ZIO[Any, AwsError, List[
      zio.aws.elasticsearch.model.RecurringCharge.ReadOnly
    ]] = AwsError.unwrapOptionField("recurringCharges", recurringCharges)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticsearch.model.ReservedElasticsearchInstanceOffering
  ) extends zio.aws.elasticsearch.model.ReservedElasticsearchInstanceOffering.ReadOnly {
    override val reservedElasticsearchInstanceOfferingId: Option[GUID] = scala
      .Option(impl.reservedElasticsearchInstanceOfferingId())
      .map(value => zio.aws.elasticsearch.model.primitives.GUID(value))
    override val elasticsearchInstanceType
        : Option[zio.aws.elasticsearch.model.ESPartitionInstanceType] = scala
      .Option(impl.elasticsearchInstanceType())
      .map(value =>
        zio.aws.elasticsearch.model.ESPartitionInstanceType.wrap(value)
      )
    override val duration: Option[Integer] = scala
      .Option(impl.duration())
      .map(value => zio.aws.elasticsearch.model.primitives.Integer(value))
    override val fixedPrice: Option[Double] =
      scala.Option(impl.fixedPrice()).map(value => value: Double)
    override val usagePrice: Option[Double] =
      scala.Option(impl.usagePrice()).map(value => value: Double)
    override val currencyCode: Option[String] =
      scala.Option(impl.currencyCode()).map(value => value: String)
    override val paymentOption: Option[
      zio.aws.elasticsearch.model.ReservedElasticsearchInstancePaymentOption
    ] = scala
      .Option(impl.paymentOption())
      .map(value =>
        zio.aws.elasticsearch.model.ReservedElasticsearchInstancePaymentOption
          .wrap(value)
      )
    override val recurringCharges
        : Option[List[zio.aws.elasticsearch.model.RecurringCharge.ReadOnly]] =
      scala
        .Option(impl.recurringCharges())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.elasticsearch.model.RecurringCharge.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticsearch.model.ReservedElasticsearchInstanceOffering
  ): zio.aws.elasticsearch.model.ReservedElasticsearchInstanceOffering.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-elasticsearch_2.13-5.17.160.1-sources.jar: zio/aws/elasticsearch/model/ReservedElasticsearchInstanceOffering.scala <==
package zio.aws.elasticsearch.model
import zio.aws.elasticsearch.model.primitives.{Integer, GUID}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ReservedElasticsearchInstanceOffering(
    reservedElasticsearchInstanceOfferingId: Option[GUID] = None,
    elasticsearchInstanceType: Option[
      zio.aws.elasticsearch.model.ESPartitionInstanceType
    ] = None,
    duration: Option[Integer] = None,
    fixedPrice: Option[Double] = None,
    usagePrice: Option[Double] = None,
    currencyCode: Option[String] = None,
    paymentOption: Option[
      zio.aws.elasticsearch.model.ReservedElasticsearchInstancePaymentOption
    ] = None,
    recurringCharges: Option[
      Iterable[zio.aws.elasticsearch.model.RecurringCharge]
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticsearch.model.ReservedElasticsearchInstanceOffering = {
    import ReservedElasticsearchInstanceOffering.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticsearch.model.ReservedElasticsearchInstanceOffering
      .builder()
      .optionallyWith(
        reservedElasticsearchInstanceOfferingId.map(value =>
          GUID.unwrap(value): java.lang.String
        )
      )(_.reservedElasticsearchInstanceOfferingId)
      .optionallyWith(elasticsearchInstanceType.map(value => value.unwrap))(
        _.elasticsearchInstanceType
      )
      .optionallyWith(duration.map(value => value: java.lang.Integer))(
        _.duration
      )
      .optionallyWith(fixedPrice.map(value => value: java.lang.Double))(
        _.fixedPrice
      )
      .optionallyWith(usagePrice.map(value => value: java.lang.Double))(
        _.usagePrice
      )
      .optionallyWith(currencyCode.map(value => value: java.lang.String))(
        _.currencyCode
      )
      .optionallyWith(paymentOption.map(value => value.unwrap))(_.paymentOption)
      .optionallyWith(
        recurringCharges.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.recurringCharges)
      .build()
  }
  def asReadOnly
      : zio.aws.elasticsearch.model.ReservedElasticsearchInstanceOffering.ReadOnly =
    zio.aws.elasticsearch.model.ReservedElasticsearchInstanceOffering
      .wrap(buildAwsValue())
}
object ReservedElasticsearchInstanceOffering {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticsearch.model.ReservedElasticsearchInstanceOffering
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.elasticsearch.model.ReservedElasticsearchInstanceOffering =
      zio.aws.elasticsearch.model.ReservedElasticsearchInstanceOffering(
        reservedElasticsearchInstanceOfferingId.map(value => value),
        elasticsearchInstanceType.map(value => value),
        duration.map(value => value),
        fixedPrice.map(value => value),
        usagePrice.map(value => value),
        currencyCode.map(value => value),
        paymentOption.map(value => value),
        recurringCharges.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def reservedElasticsearchInstanceOfferingId: Option[GUID]
    def elasticsearchInstanceType
        : Option[zio.aws.elasticsearch.model.ESPartitionInstanceType]
    def duration: Option[Integer]
    def fixedPrice: Option[Double]
    def usagePrice: Option[Double]
    def currencyCode: Option[String]
    def paymentOption: Option[
      zio.aws.elasticsearch.model.ReservedElasticsearchInstancePaymentOption
    ]
    def recurringCharges
        : Option[List[zio.aws.elasticsearch.model.RecurringCharge.ReadOnly]]
    def getReservedElasticsearchInstanceOfferingId: ZIO[Any, AwsError, GUID] =
      AwsError.unwrapOptionField(
        "reservedElasticsearchInstanceOfferingId",
        reservedElasticsearchInstanceOfferingId
      )
    def getElasticsearchInstanceType: ZIO[
      Any,
      AwsError,
      zio.aws.elasticsearch.model.ESPartitionInstanceType
    ] = AwsError.unwrapOptionField(
      "elasticsearchInstanceType",
      elasticsearchInstanceType
    )
    def getDuration: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("duration", duration)
    def getFixedPrice: ZIO[Any, AwsError, Double] =
      AwsError.unwrapOptionField("fixedPrice", fixedPrice)
    def getUsagePrice: ZIO[Any, AwsError, Double] =
      AwsError.unwrapOptionField("usagePrice", usagePrice)
    def getCurrencyCode: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("currencyCode", currencyCode)
    def getPaymentOption: ZIO[
      Any,
      AwsError,
      zio.aws.elasticsearch.model.ReservedElasticsearchInstancePaymentOption
    ] = AwsError.unwrapOptionField("paymentOption", paymentOption)
    def getRecurringCharges: ZIO[Any, AwsError, List[
      zio.aws.elasticsearch.model.RecurringCharge.ReadOnly
    ]] = AwsError.unwrapOptionField("recurringCharges", recurringCharges)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticsearch.model.ReservedElasticsearchInstanceOffering
  ) extends zio.aws.elasticsearch.model.ReservedElasticsearchInstanceOffering.ReadOnly {
    override val reservedElasticsearchInstanceOfferingId: Option[GUID] = scala
      .Option(impl.reservedElasticsearchInstanceOfferingId())
      .map(value => zio.aws.elasticsearch.model.primitives.GUID(value))
    override val elasticsearchInstanceType
        : Option[zio.aws.elasticsearch.model.ESPartitionInstanceType] = scala
      .Option(impl.elasticsearchInstanceType())
      .map(value =>
        zio.aws.elasticsearch.model.ESPartitionInstanceType.wrap(value)
      )
    override val duration: Option[Integer] =
      scala.Option(impl.duration()).map(value => value: Integer)
    override val fixedPrice: Option[Double] =
      scala.Option(impl.fixedPrice()).map(value => value: Double)
    override val usagePrice: Option[Double] =
      scala.Option(impl.usagePrice()).map(value => value: Double)
    override val currencyCode: Option[String] =
      scala.Option(impl.currencyCode()).map(value => value: String)
    override val paymentOption: Option[
      zio.aws.elasticsearch.model.ReservedElasticsearchInstancePaymentOption
    ] = scala
      .Option(impl.paymentOption())
      .map(value =>
        zio.aws.elasticsearch.model.ReservedElasticsearchInstancePaymentOption
          .wrap(value)
      )
    override val recurringCharges
        : Option[List[zio.aws.elasticsearch.model.RecurringCharge.ReadOnly]] =
      scala
        .Option(impl.recurringCharges())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.elasticsearch.model.RecurringCharge.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticsearch.model.ReservedElasticsearchInstanceOffering
  ): zio.aws.elasticsearch.model.ReservedElasticsearchInstanceOffering.ReadOnly =
    new Wrapper(impl)
}
